==> ugene_1.20.0%2Bdfsg.orig.tar.xz: ugene-1.20.0/src/plugins/GUITestBase/src/tests/common_scenarios/project/sequence_exporting/from_project_view/GTTestsFromProjectView.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_FROM_PROJECT_VIEW_H_
#define _U2_GUI_TEST_FROM_PROJECT_VIEW_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_project_sequence_exporting_from_project_view {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_project_sequence_exporting_from_project_view"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0005_1)
GUI_TEST_CLASS_DECLARATION(test_0005_2)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0007_1)
GUI_TEST_CLASS_DECLARATION(test_0007_2)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0008_2)

#undef GUI_TEST_SUITE
}

} //namespace

#endif // _U2_GUI_TEST_FROM_PROJECT_VIEW_H_

==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins/GUITestBase/src/tests/common_scenarios/project/sequence_exporting/from_project_view/GTTestsFromProjectView.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_FROM_PROJECT_VIEW_H_
#define _U2_GUI_TEST_FROM_PROJECT_VIEW_H_

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_project_sequence_exporting_from_project_view {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_project_sequence_exporting_from_project_view"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0005_1)
GUI_TEST_CLASS_DECLARATION(test_0005_2)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0007_1)
GUI_TEST_CLASS_DECLARATION(test_0007_2)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0008_2)

#undef GUI_TEST_SUITE
}

} //namespace

#endif // _U2_GUI_TEST_FROM_PROJECT_VIEW_H_
